from ..libs.ecdsa.curves import SECP256k1
from ..libs.ecdsa.keys import SigningKey, VerifyingKey


class Ecdsa:

    def __init__(self, publicPem=None, privatePem=None):
        self.privateKey = SigningKey.from_pem(privatePem) if privatePem else SigningKey.generate(curve=SECP256k1)
        self.publicKey = VerifyingKey.from_pem(publicPem) if publicPem else self.privateKey.get_verifying_key()

    def publicKeyPem(self):
        return self.publicKey.to_pem()

    def privateKeyPem(self):
        return self.privateKey.to_pem()

    def sign(self, payload):
        return self.privateKey.sign(payload).decode("latin-1")

    def isValidSignature(self, signature, message):
        try:
            self.publicKey.verify(signature.encode("latin-1"), message)
            return True
        except:
            return False